# FieldOptions3

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**precision** | **float** | Number of digits shown to the right of the decimal point (0-7 inclusive) | [optional] 
**symbol** | **str** | Currency symbol to use | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

